#!/bin/sh
cd "$HOME"

if [ -f "$HOME/.userinfo" ]; then
    source "$HOME/.userinfo"
else
    logger -t notes8-setup -- waitung 5 seconds for .userinfo
    sleep 5
    if [ -f "$HOME/.userinfo" ]; then
	source "$HOME/.userinfo"
    fi
fi

if [ -d ".mozilla/eclipse" ]; then
    cp ".mozilla/firefox"/*.default/*.db ".mozilla/firefox/"*.default/*.txt ".mozilla/firefox/"*.default/*.js .mozilla/eclipse
    logger -t notes8-setup -- copied firefox config to notes internal webbrowser config
fi

if [ -x "/opt/ibm/lotus/notes/notes" -a -f ".daily.pem" ]; then
    if [ ! -d "lotus/notes/data" ]; then 
	logger -t notes8-setup -- creating notes data directory
	mkdir -p "lotus/notes/data"
	mkdir -p "lotus/notes/data/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/"
	cat >"lotus/notes/data/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/com.ibm.rcp.ui.browser.launcher.prefs" <<EOF
#Wed Jan 28 20:34:55 CET 2009
USER_DEFINED_HOME_PAGE=about\:blank
eclipse.preferences.version=1
USE_EMBEDDED_BROWSER=false

EOF
	# cat >"lotus/notes/data/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/com.ibm.rcp.personality.framework.prefs" <<EOF
#Wed Jan 28 20:34:54 CET 2009
# DEFAULT_RESTORE_TABS_PREFERENCE=false
# RESTORE_TABS=false
# eclipse.preferences.version=1
#
#EOF
    fi

    admin_server="ltlvm40"
    admin="https://inotes.lvm.de/$admin_server/admin"
    IDFILE="lotus/notes/data/$LVMUID.id"

    if [ ! -f "lotus/notes/data/password.txt" -a -f "/opt/ibm/lotus/notes/libextpsw.so" ]; then
	database=zgkw_rel85.nsf
	logger -t notes8-setup -- getting password from $database
	LNPW=$(curl -s -S --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem "$admin/$database/encryptedpassword.txt")
	echo "$LNPW" >"lotus/notes/data/password.txt"
	logger -t notes8-setup -- got password $(wc -c <"lotus/notes/data/password.txt")
	if [ -f "$IDFILE" ]; then
	    mv "$IDFILE" "$IDFILE.preZGKW"
	fi
	database=id_names_rel85.nsf
	logger -t notes8-setup -- getting ID File from "$database"
	curl -o "$IDFILE" --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem "$admin/$database/(byPersNrString)/$LVMUID/\$File/$LVMUID.id"
	logger -t notes8-setup -- got ID File: $(wc -c <"$IDFILE")
	if [ -f "lotus/notes/data/notes.ini" ]; then 
	    sed -e "/^Key[Ff]ile[Nn]ame=/ d" -e "/^Install[Tt]ype=/ aKeyFileName=$LVMUID.id" -i "lotus/notes/data/notes.ini"
	fi
    fi

    if [ ! -f "$IDFILE" ]; then
	database=id_names_rel85.nsf
	logger -t notes8-setup -- getting ID File from "$database"
	curl -o "$IDFILE" --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem "$admin/$database/(byPersNrString)/$LVMUID/\$File/$LVMUID.id"
	logger -t notes8-setup -- got ID File: $(wc -c <"$IDFILE")
    fi

    if [ ! -f "lotus/notes/data/setup.txt" ]; then
	database=id_names_rel85.nsf
	logger -t notes8-setup -- getting setup.txt from $database
	curl -o "lotus/notes/data/setup.txt" --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem "$admin/$database/setup.txt"
	logger -t notes8-setup -- got setup.txt: $(wc -c <"lotus/notes/data/setup.txt")
    fi
    
    if [ ! -f "lotus/notes/data/notes.ini" ]; then 
	logger -t notes8-setup -- creating initial notes.ini
	cat >"lotus/notes/data/notes.ini" <<EOF
[Notes]
Directory=$HOME/lotus/notes/data
KitType=1
SharedDataDirectory=/opt/ibm/lotus/notes/data/shared
DND_ENABLED=1
InstallType=6
Location=Online,8FA
TCPIP=TCP, 0, 15, 0
Ports=TCPIP
KeyFileName=$LVMUID.id
ExtMgr_AddIns=libextpsw.so,libmc.so
MC_DB=%notes_homeserver%!!admin/mc_konfiguration.nsf
MC_DB_NotResolvable=CN=LTLVM405/O=LVM/C=DE!!admin/mc_konfiguration.nsf
MC_WorkingDirectory=%notes_data%/marvel
MC_AllowSyncDuringSetup=1
ConfigFile=$HOME/lotus/notes/data/setup.txt
EOF
    fi
    logger -t notes8-setup -- finished ...
fi

if [ -r "lotus/notes/data/password.txt" ]; then
    LNPW=$(cat lotus/notes/data/password.txt)
    logger -t notes8-setup -- SSO setup OK
else
    LNPW=""
    logger -t notes8-setup -- SSO setup failed
fi
export LNPW
if [ -f "lotus/notes/data/notes.ini" ]; then
    addins=""
    if [ -f /opt/ibm/lotus/notes/libextpsw.so ]; then
	addins="${addins}libextpsw.so,"
	logger -t notes8-setup -- activating SSO
    fi
    if [ -f /opt/ibm/lotus/notes/libmc.so ]; then
	addins="${addins}libmc.so,"
	logger -t notes8-setup -- activating marvel client
    fi
    sed \
	-e "/^ExtMgr_AddIns=/ d" \
	-e "/^MC_DB=/ d" -e "/^MC_WorkingDirectory=/ d" -e "/^MC_DB_NotResolvable=/ d" -e "/^MC_AllowSyncDuringSetup=/ d" \
	-e "/^Key[Ff]ile[Nn]ame=/ aExtMgr_AddIns=${addins%%,}\nMC_DB=%notes_homeserver%!!admin\/mc_konfiguration.nsf\nMC_DB_NotResolvable=CN=LTLVM405/O=LVM/C=DE!!admin/mc_konfiguration.nsf\nMC_WorkingDirectory=%notes_data%\/marvel\nMC_AllowSyncDuringSetup=1" \
	-i "lotus/notes/data/notes.ini"
    logger -t notes8-setup -- setup notes.ini with extensions ${addins%%,}
fi

if [ "$notesclientuser" = "" ] ; then
    if [ -f "lotus/notes/data/notes.ini" ]; then
	notesclientuser=true
    else
	notesclientuser=false
    fi
fi
if [ -f "lotus/notes/data/log.nsf" ]; then
    notesclientuser=true
fi
if "$notesclientuser"; then
    rm -f ".local/share/applications/Lotus Notes 8.5.desktop"
    if [ -f /usr/share/applications/inotes-mail.desktop ]; then
	cat >".local/share/applications/inotes-mail.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=LVM-Mail
Comment=Mail im Notes Client
Exec=/opt/ibm/lotus/notes/notes notes:///0000000000000e00
Terminal=false
Type=Application
Categories=LVM-TopLevel;LVM;
Icon=/opt/ibm/lotus/notes/notes.ico
EOF
    fi
    if [ -f /usr/share/applications/notes-portal-id.desktop ]; then
	cat >".local/share/applications/notes-portal-id.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=LVM Portal
Comment=LVM Portal im Notes Client
Exec=/opt/ibm/lotus/notes/notes notes:///c125709100284ae3 
Terminal=false
Type=Application
Categories=GNOME;GTK;Application;LVM-TopLevel;LVM;
Icon=notes-portal-id.png
EOF
    fi
    if [ -f /usr/share/applications/notes-portal-ad.desktop ]; then
	cat >".local/share/applications/notes-portal-ad.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=LVM Agentur Portal
Comment=LVM Portal im Notes Client
Exec=/opt/ibm/lotus/notes/notes notes:///c1256faf004f45ea
Terminal=false
Type=Application
Categories=GNOME;GTK;Application;LVM-TopLevel;LVM;
Icon=notes-portal-ad.png
EOF
    fi
else
    logger -t notes8-setup -- hiding notes client starter
    sed -e '/^NoDisplay=true/d' -e '/^Terminal=false/ aNoDisplay=true' > ".local/share/applications/Lotus Notes 8.5.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Lotus Notes 8.5
Type=Application
Exec=/opt/ibm/lotus/notes/framework/../notes 
Icon=/opt/ibm/lotus/notes/framework/shared/eclipse/features/com.ibm.notes.links.feature_8.5.0.20081211-1925/icons/notes.ico
Terminal=false
Categories=Application;Office;
EOF
    rm -f ".local/share/applications/inotes-mail.desktop" \
	".local/share/applications/notes-portal-id.desktop" \
	".local/share/applications/notes-portal-ad.desktop"
fi

# Eigene Maildatenbank Notes:///0000000000000E00 
# Agentur Portal Notes:///C1256FAF004F45EA
# Innendienst Portal Notes:///C125709100284AE3 